@@ -172,7 +172,7 @@ impl Api {
         self.post("/clusters", body).await
     }
 
-    pub(crate) async fn unregister_cluster(&self, name: v0::ClusterName) -> ApiResult<()> {
+    pub(crate) async fn unregister_cluster(&self, name: &v0::ClusterName) -> ApiResult<()> {
         let path = format!("/clusters/{name}", name = name);
         self.del(path).await
     }
