@@ -24,6 +24,7 @@ pub(super) struct RegisterCluster {
     default_state: Option<String>,
     claim_unowned_states: bool,
     cleanup_grace: String,
+    install_state_crd: bool,
     azure: AzureCredentials,
 }
 
@@ -37,6 +38,7 @@ impl RegisterCluster {
         default_state: Option<String>,
         claim_unowned_states: bool,
         cleanup_grace: String,
+        install_state_crd: bool,
         azure: AzureCredentials,
     ) -> Self {
         Self {
@@ -47,6 +49,7 @@ impl RegisterCluster {
             default_state,
             claim_unowned_states,
             cleanup_grace,
+            install_state_crd,
             azure,
         }
     }
@@ -61,7 +64,7 @@ impl StateHub {
         &self,
         kubectl: k8s::Kubectl,
         locations: &[Location],
-        register_cluster: RegisterCluster,
+        register_cluster: &RegisterCluster,
     ) -> anyhow::Result<()> {
         let provider = match register_cluster.provider {
             Some(provider) => provider,
@@ -86,9 +89,11 @@ impl StateHub {
             locations.show(),
         ))?;
 
-        kubectl.install_statehub_cluster(namespace).await?;
+        kubectl
+            .install_statehub_cluster(namespace, register_cluster.install_state_crd)
+            .await?;
 
-        self.setup_cluster_token_helper(&cluster, &register_cluster)
+        self.setup_cluster_token_helper(&cluster, register_cluster)
             .await?;
         self.setup_credentials_helper(
             &kubectl,
@@ -97,16 +102,15 @@ impl StateHub {
             None,
         )
         .await?;
-        self.setup_configmap_helper(&kubectl, &cluster, &register_cluster)
+        self.setup_configmap_helper(&kubectl, &cluster, register_cluster)
             .await?;
 
         if register_cluster.claim_unowned_states {
-            self.claim_unowned_states_helper(&cluster, &register_cluster)
+            self.claim_unowned_states_helper(&cluster, register_cluster)
                 .await?;
         }
 
-        self.helm_install_helper(&cluster, &register_cluster)
-            .await?;
+        self.helm_install_helper(&cluster, register_cluster).await?;
 
         cluster.print(&self.stdout, self.json)
     }
